Problem

Struct Problem 

pub struct Problem<'a, E>
where E: FnMut(&[f64], &mut [f64]) -> Result<f64>,
{ pub x: &'a mut [f64], pub fx: f64, pub gx: Vec<f64>, /* private fields */ }
Represents an optimization problem.

Problem holds input variables x, gradient gx arrays, and function value fx.

Fields

x: &'a mut [f64]

x is an array of length n. on input it must contain the base point for the line search.

fx: f64

fx is a variable. It must contain the value of problem f at x.

gx: Vec<f64>

gx is an array of length n. It must contain the gradient of f at x.

Implementations

Source

impl<'a, E> Problem<'a, E>
where E: FnMut(&[f64], &mut [f64]) -> Result<f64>,

pub fn new(x: &'a mut [f64], eval: E, owlqn: Option<Orthantwise>) -> Self

Initialize problem with array length n

pub fn dginit(&self) -> Result<f64>

Compute the initial gradient in the search direction.

pub fn update_search_direction(&mut self)

Update search direction using evaluated gradient.

pub fn search_direction(&self) -> &[f64]

Return a reference to current search direction vector

pub fn search_direction_mut(&mut self) -> &mut [f64]

Return a mutable reference to current search direction vector

pub fn dg_unchecked(&self) -> f64

Compute the gradient in the search direction without sign checking.

pub fn evaluate(&mut self) -> Result<()>

pub fn number_of_evaluation(&self) -> usize

Return total number of evaluations.

pub fn evaluated(&self) -> bool

Test if Problem has been evaluated or not

pub fn clone_from(&mut self, src: &Problem<'_, E>)

Copies all elements from src into self.

pub fn take_line_step(&mut self, step: f64)

Take a line step along search direction.

Compute the current value of x: x <- x + (*step) * d.

pub fn gnorm(&self) -> f64

Return gradient vector norm: ||gx||

pub fn xnorm(&self) -> f64

Return position vector norm: ||x||

pub fn orthantwise(&self) -> bool

pub fn revert(&mut self)

Revert to previous step

pub fn save_state(&mut self)

Store the current position and gradient vectors.

pub fn constrain_search_direction(&mut self)

Constrain the search direction for orthant-wise updates.

pub fn update_owlqn_gradient(&mut self)